JasonWoof Got questions, comments, patches, etc.? Contact Jason Woofenden
using EXIT_stuff in exit() now
[dwm.git] / tag.c
diff --git a/tag.c b/tag.c
index 0861128..5da5711 100644 (file)
--- a/tag.c
+++ b/tag.c
@@ -2,71 +2,38 @@
  * (C)opyright MMVI Anselm R. Garbe <garbeam at gmail dot com>
  * See LICENSE file for license details.
  */
+#include "dwm.h"
 
-#include <stdlib.h>
-#include <stdio.h>
 #include <string.h>
-#include <X11/Xatom.h>
 #include <X11/Xutil.h>
 
-#include "dwm.h"
+/* static */
 
+/* CUSTOMIZE */ 
 static Rule rule[] = {
/* class                        instance        tags                                            dofloat */
        { "Firefox-bin",        "Gecko",        { [Twww] = "www" },                     False },
 };
 
-void (*arrange)(Arg *) = dotile;
+/* extern */
 
-Client *
-getnext(Client *c)
-{
-       for(; c && !c->tags[tsel]; c = c->next);
-       return c;
-}
+/* CUSTOMIZE */
+char *tags[TLast] = {
+       [Tscratch] = "scratch",
+       [Tdev] = "dev",
+       [Twww] = "www",
+       [Twork] = "work",
+};
+void (*arrange)(Arg *) = dotile;
 
 void
-settags(Client *c)
+appendtag(Arg *arg)
 {
-       XClassHint ch;
-       static unsigned int len = rule ? sizeof(rule) / sizeof(rule[0]) : 0;
-       unsigned int i, j;
-       Bool matched = False;
-
-       if(!len) {
-               c->tags[tsel] = tags[tsel];
+       if(!sel)
                return;
-       }
-
-       if(XGetClassHint(dpy, c->win, &ch)) {
-               if(ch.res_class && ch.res_name) {
-                       for(i = 0; i < len; i++)
-                               if(!strncmp(rule[i].class, ch.res_class, sizeof(rule[i].class))
-                                       && !strncmp(rule[i].instance, ch.res_name, sizeof(rule[i].instance)))
-                               {
-                                       for(j = 0; j < TLast; j++)
-                                               c->tags[j] = rule[i].tags[j];
-                                       c->dofloat = rule[i].dofloat;
-                                       matched = True;
-                                       break;
-                               }
-               }
-               if(ch.res_class)
-                       XFree(ch.res_class);
-               if(ch.res_name)
-                       XFree(ch.res_name);
-       }
 
-       if(!matched)
-               c->tags[tsel] = tags[tsel];
-}
-
-void
-view(Arg *arg)
-{
-       tsel = arg->i;
+       sel->tags[arg->i] = tags[arg->i];
        arrange(NULL);
-       drawall();
 }
 
 void
@@ -99,7 +66,7 @@ dotile(Arg *arg)
        w = sw - mw;
        arrange = dotile;
        for(n = 0, c = clients; c; c = c->next)
-               if(c->tags[tsel] && !c->dofloat)
+               if(c->tags[tsel] && !c->isfloat)
                        n++;
 
        if(n > 1)
@@ -109,7 +76,7 @@ dotile(Arg *arg)
 
        for(i = 0, c = clients; c; c = c->next) {
                if(c->tags[tsel]) {
-                       if(c->dofloat) {
+                       if(c->isfloat) {
                                higher(c);
                                resize(c, True);
                                continue;
@@ -147,14 +114,11 @@ dotile(Arg *arg)
        drawall();
 }
 
-void
-appendtag(Arg *arg)
+Client *
+getnext(Client *c)
 {
-       if(!sel)
-               return;
-
-       sel->tags[arg->i] = tags[arg->i];
-       arrange(NULL);
+       for(; c && !c->tags[tsel]; c = c->next);
+       return c;
 }
 
 void
@@ -169,3 +133,46 @@ replacetag(Arg *arg)
        appendtag(arg);
 }
 
+void
+settags(Client *c)
+{
+       XClassHint ch;
+       static unsigned int len = rule ? sizeof(rule) / sizeof(rule[0]) : 0;
+       unsigned int i, j;
+       Bool matched = False;
+
+       if(!len) {
+               c->tags[tsel] = tags[tsel];
+               return;
+       }
+
+       if(XGetClassHint(dpy, c->win, &ch)) {
+               if(ch.res_class && ch.res_name) {
+                       for(i = 0; i < len; i++)
+                               if(!strncmp(rule[i].class, ch.res_class, sizeof(rule[i].class))
+                                       && !strncmp(rule[i].instance, ch.res_name, sizeof(rule[i].instance)))
+                               {
+                                       for(j = 0; j < TLast; j++)
+                                               c->tags[j] = rule[i].tags[j];
+                                       c->isfloat = rule[i].isfloat;
+                                       matched = True;
+                                       break;
+                               }
+               }
+               if(ch.res_class)
+                       XFree(ch.res_class);
+               if(ch.res_name)
+                       XFree(ch.res_name);
+       }
+
+       if(!matched)
+               c->tags[tsel] = tags[tsel];
+}
+
+void
+view(Arg *arg)
+{
+       tsel = arg->i;
+       arrange(NULL);
+       drawall();
+}
@@ -2,71 +2,38 @@
 static Rule rule[] = {
-       /* class                        instance        tags                                            dofloat */
+       /* class                        instance        tags                                            isfloat */
        { "Firefox-bin",        "Gecko",        { [Twww] = "www" },                     False },
 };